@@ -113,16 +113,20 @@ def get_stanza_features(poem_features):
     :return: dict list
         Stanzas dict list
     """
+    manually_checked = poem_features['manually_checked']
+    author = poem_features['author']
+    corpus_name = poem_features['corpus']
     stanza_list = []
     for stanza_index, key in enumerate(poem_features["stanzas"]):
         stanza_features = poem_features['stanzas'][stanza_index]
         dic_final = {
             'stanza_number': stanza_features['stanza_number'],
-            'manually_checked': poem_features['manually_checked'],
+            'manually_checked': manually_checked,
             'poem_title': poem_features['poem_title'],
-            'author': poem_features['author'],
+            'author': author,
             'stanza_text': stanza_features['stanza_text'],
-            'stanza_type': stanza_features['stanza_type']
+            'stanza_type': stanza_features['stanza_type'],
+            'corpus': corpus_name,
         }
         stanza_list.append(dic_final)
     return stanza_list
@@ -262,11 +266,7 @@ def write_json(poem_dict, filename):
     """
     if filename.endswith(".json"):
         filename, *_ = filename.rsplit(".json", 1)
-    file_path = Path(filename)
-    if os.path.exists(f"{filename}.json"):
-        file_count = len(list(file_path.parent.glob(f"{file_path.stem}*.json")))
-        filename = f"{filename}{file_count + 1}"
-    with open(filename + ".json", 'w', encoding='utf-8') as f:
+    with open(f"{filename}.json", 'w', encoding='utf-8') as f:
         json.dump(poem_dict, f, ensure_ascii=False, indent=4)
 
 
