@@ -7,7 +7,7 @@ from averell.readers.forbetter4verse import get_features
 from averell.readers.forbetter4verse import parse_xml
 from tests.test_utils import FIXTURES_DIR
 
-poems = FIXTURES_DIR / "poems"
+FORB4V_PATH = FIXTURES_DIR / "4b4v"
 
 
 @pytest.fixture
@@ -17,12 +17,13 @@ def forbetter4verse():
 
 
 def test_parse_xml(forbetter4verse):
-    path = poems / "input_4better4verse.xml"
-    poem = parse_xml(str(path))
+    path = (FORB4V_PATH / "for_better_for_verse-master" / "poems" /
+            "input_4better4verse.xml")
+    poem = parse_xml(path)
     assert poem == forbetter4verse
 
 
-@patch('averell.readers.forbetter4verse.parse_xml')
+@patch('averell.readers.forbetter4verse.parse_xml', return_value={})
 def test_get_features(mock_poem_info):
-    mock_poem_info.return_value = {}
-    assert [] == get_features(FIXTURES_DIR)
+    assert [{}] == get_features(FORB4V_PATH)
+    assert mock_poem_info.called
