@@ -39,7 +39,7 @@ def test_download_2(mock_download, caplog):
 def test_export_no_ids(caplog):
     expected = "Using corpora folder: './corpora'\n"
     runner = CliRunner()
-    result = runner.invoke(export, [])
+    result = runner.invoke(export, ["--no-download"])
 
     assert result.output == expected
     assert result.exit_code == 0
@@ -49,7 +49,7 @@ def test_export_no_ids(caplog):
 def test_export_not_downloaded(caplog):
     expected = "Using corpora folder: './corpora'\n"
     runner = CliRunner()
-    result = runner.invoke(export, ["1", "--granularity", "line"])
+    result = runner.invoke(export, ["1", "--granularity", "line", "--no-download"])
     assert result.output == expected
     assert result.exit_code == 0
 
@@ -57,10 +57,10 @@ def test_export_not_downloaded(caplog):
 @patch('averell.utils.CORPORA_SOURCES', _corpora_sources)
 def test_list():
     expected = "\n".join([
-        '  id  name      size      docs    words  granularity    license',
-        '----  --------  ------  ------  -------  -------------  ---------',
-        '   1  testing   22M       4088   381539  stanza         CC-BY',
-        '   2  testing2  22M       4088   381539  stanza         CC-BY\n',
+        '  id  name           lang    size      docs    words  granularity    license',
+        '----  -------------  ------  ------  ------  -------  -------------  ---------',
+        '   1  testing (t1)   es      22M       4088   381539  stanza         CC-BY',
+        '   2  testing2 (t2)  fr      22M       4088   381539  stanza         CC-BY\n',
         ])
     runner = CliRunner()
     result = runner.invoke(list_command, [])
