@@ -7,6 +7,8 @@ from averell.readers.disco3 import get_features
 from averell.readers.disco3 import parse_xml
 from tests.test_utils import TESTS_DIR
 
+DISCO3_PATH = (TESTS_DIR / "fixtures" / "disco3")
+
 
 @pytest.fixture
 def disco3():
@@ -15,13 +17,13 @@ def disco3():
 
 
 def test_parse_xml(disco3):
-    path = TESTS_DIR / "fixtures" / "input_disco3.xml"
-    poem = parse_xml(str(path))
+    path = (DISCO3_PATH / "disco-3" / "tei" / "19th" /
+            "per-sonnet" / "input_disco3.xml")
+    poem = parse_xml(path)
     assert poem == disco3
 
 
-@patch('averell.readers.disco3.parse_xml')
+@patch('averell.readers.disco3.parse_xml', return_value={})
 def test_get_features(mock_parse_xml):
-    path = TESTS_DIR / "fixtures" / "test"
-    mock_parse_xml.return_value = {}
-    assert [{}] == get_features(path)
+    assert [{}] == get_features(DISCO3_PATH)
+    assert mock_parse_xml.called
